#include "config.h"

#include <iostream>
#include <string>
#include <cassert>

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include <errno.h>

#include "types.h"
#include "error.h"
#include "estring.h"
#include "fs.h"
#include "tstamp.h"
#include "rconfig.h"
#include "test-rconfig-setup.h"

// #define ERR_OUT(e) std::cerr << e;
#define ERR_OUT(e)

void test(void)
{
	char *argv[256] = { 0 };
	int argc = 0;
	bool thrown = false;

	argv[argc++] = "<program>";
	argv[argc++] = "--archive";

	config.default_file("./test-rconfig.dir/global-vault.dir/file-3.conf");
	config.default_logdir("./test-rconfig.dir/log.dir");
	try {
		config.init(argc, argv);
	}
	catch(error e) {
		ERR_OUT(e);
		assert(e.num() == 20);
		assert(!e.internal());
		assert(e.size() == 3);
		assert(e[0].what() == "Invalid vault path: \"./test-rconfig.dir/global-vault.dir/file-1.conf\"");
		assert(e[1].what() == "For paths found matching: \"./test-rconfig.dir/global-vault.dir/*\"");
		assert(e[2].what() == "At ./test-rconfig.dir/global-vault.dir/file-3.conf[2]");
		thrown = true;
	}
	catch(...) {
		assert(0);
	}
	assert(thrown);
	assert(config.vaults().size() == 1);
	assert(config.vaults()[0] 
		== "./test-rconfig.dir/global-vault.dir/00-vault.dir");
}

int main(int argc, char *argv[])
{
	cleanup();
	setup();
	try {
		test();
	}
	catch(error e) {
		std::cerr << e;
		assert(0);
	}
	catch(...) {
		std::cerr << err_unknown;
		assert(0);
	}
	cleanup();
	return(0);
}

